﻿using System;
using System.Collections.Generic;
using System.Text;
using WinGetOpt;
using System.Drawing;

namespace CaptureSiteToJpg {
	class Program {

		// 解析済みのコマンドラインオプション
		static CommandLine cmd;

		[STAThread]
		static int Main( string[] args ) {
			string url;
			string fileName;

			//--------------------------------------------------------
			// コマンドラインパラメータを取得する
			//--------------------------------------------------------
			cmd = getParam( Environment.GetCommandLineArgs() );
			if ( !cmd.HasOption( "url" ) ||  !cmd.HasOption( "out" ) ) {
				showUsage();
				return 1;
			}

			url      = cmd.GetOptionValue( "url" );
			fileName = cmd.GetOptionValue( "out" );

			//--------------------------------------------------------
			// パラメータで指定されたサイトの画像を取得する　
			//--------------------------------------------------------
			Bitmap bitmap = SiteCaptureSharp.CaptureManager.getBitmapFromUrl( url );
			if ( bitmap == null ) {
				System.Console.Error.WriteLine( "サイト画像の取得に失敗しました" );
				return 2;
			}

			//--------------------------------------------------------
			// 取得した画像をファイルに保存する
			//--------------------------------------------------------
			bitmap.Save( fileName, System.Drawing.Imaging.ImageFormat.Jpeg );

			return 0;
		}


		private static void showUsage() {
			Console.WriteLine( "usage:" );
			Console.WriteLine( "CaptureSiteToJpg.exe /url siteUrl /out fileName" );
			Console.WriteLine( "" );
			Console.WriteLine( "ex: CaptureSiteToJpg.exe /url http://www.yahoo.co.jp/ /out yahoo.jpg" );
		}


		//*******************************************************************
		/// <summary>起動引数を取得する
		/// </summary>
		/// <param name="mws"></param>
		//*******************************************************************
		private static CommandLine getParam( String[] args ) {
			Options optdef;
 
			//---------------------------------------------------------
			// オプションの定義を行う(optName, hasArg, description)
			//---------------------------------------------------------
			optdef = new Options();
			optdef.AddOption( "url",      true , "URL"   );
			optdef.AddOption( "out",      true , "出力ファイル名" );

			//---------------------------------------------------------
			// コマンドラインオプションを解析する
			//---------------------------------------------------------
			OptionParser parser = new OptionParser();
			return parser.parse( optdef, args );
		}
	}
}
