﻿
using System;
using System.Collections.Generic;
using System.Text;

namespace WinGetOpt {

	//*************************************************************************
	/// <summary>	コマンドライン引数のオプション定義を管理する
	/// </summary>
	/// <author>	aka(nanoappli.com)</author>
	//*************************************************************************
	public class Options {
		List<Option> OptionList;

		public Options() {
			OptionList = new List<Option>();
		}

		//*********************************************************************
		/// <summary>	オプション定義を追加する
		/// </summary>
		/// <param name="optName">  オプション名</param>
		/// <param name="hasArg">   パラメータを持つか</param>
		/// <param name="desc">     オプションの説明</param>
		/// <returns>自分自身</returns>
		//*********************************************************************
		public Options AddOption( string optName, bool hasArg, string desc ) {					
			OptionList.Add( new Option( optName, hasArg, desc ) );
			return this;
		}


		//*********************************************************************
		/// <summary> 指定された名称のオプションが定義されているかを返す
		/// </summary>
		/// <returns>true:存在する,　false:存在しない</returns>
		//*********************************************************************
		public bool HasOption( string optName ) {
			// 全オプション定義をテック
			foreach ( Option opt in OptionList ) {
				if ( opt.OptName.Equals( optName ) ) {
					// 存在した
					return true;
				}	
			}

			// 全部調べても見つからなかった...
			return false;
		}


		//*********************************************************************
		/// <summary> 指定された名称のオプションを返す
		/// </summary>
		/// <returns></returns>
		//*********************************************************************
		public Option GetOption( string optName ) {
			// 全オプション定義をテック
			foreach ( Option opt in OptionList ) {
				if ( opt.OptName.Equals( optName ) ) {
					// 存在した
					return opt;
				}	
			}

			// 全部調べても見つからなかった...
			return null;
		}
	}

	//*********************************************************************
	/// <summary>	個々のオプション定義を管理する 
	/// </summary>
	/// <author>	aka(nanoappli.com)</author>
	//*********************************************************************
	public class Option {
		/// <summary> オプションの名称</summary>
		public string OptName     { get; set; }

		/// <summary>そのオプションがパラメータを持つか</summary>
		public bool   HasArg      { get; set; }

		/// <summary>オプションの説明</summary>
		public string Description { get; set; }

		//*********************************************************************
		/// <summary>	コンストラクタ
		/// </summary>
		/// <param name="optName">	オプション名</param>
		/// <param name="hasArg">	パラメータを持つか</param>
		/// <param name="desc">		オプションの説明</param>
		/// <param name="required"> 必須項目か[true:必須, false:任意]</param>
		//*********************************************************************
		public Option( String optName, Boolean hasArg, String desc ) {
			OptName		= optName;
			HasArg      = hasArg;
			Description = desc;
		}
	}
}
